@@ -1,34 +1,27 @@
 package Vim::Complete;
-
+use 5.006;
 use strict;
 use warnings;
 use PPI;
 use File::Find;
 use File::Spec;
-
-
-our $VERSION = '0.03';
-
-
+our $VERSION = '0.04';
 use base qw(Class::Accessor::Complex);
-
-
+#<<<
 __PACKAGE__
     ->mk_new
     ->mk_scalar_accessors(qw(min_length))
     ->mk_array_accessors(qw(dirs))
     ->mk_hash_accessors(qw(result))
     ->mk_boolean_accessors(qw(verbose));
-
+#>>>
 
 sub gather {
     my ($self, $filename) = @_;
 
     # does PPI not like relative filenames?
     $filename = File::Spec->rel2abs($filename);
-
     my $document = PPI::Document->new($filename);
-
     unless (UNIVERSAL::isa($document, 'PPI::Document')) {
         warn "couldn't parse $filename\n";
         return;
@@ -36,29 +29,23 @@ sub gather {
 
     # get a hash reference so we can change the hash in place
     my $result = $self->result;
-
     my $min_length = $self->min_length || 3;
-
-    $result->{$_} = 1 for
-        grep { /\w{$min_length,}/ }
-        map  { $_->namespace }
-        @{ $document->find('PPI::Statement::Package') || [] };
-
-    $result->{$_} = 1 for
-        grep { /\w{$min_length,}/ }
-        map  { substr($_, 0, 1, ''); $_ }
-        map  { $_->variables }
-        @{ $document->find('PPI::Statement::Variable') || [] };
-
-    $result->{$_} = 1 for
-        grep { /\w{$min_length,}/ }
-        map  { $_->name }
-        @{ $document->find('PPI::Statement::Sub') || [] };
+    $result->{$_} = 1
+      for grep { /\w{$min_length,}/ }
+      map      { $_->namespace }
+      @{ $document->find('PPI::Statement::Package') || [] };
+    $result->{$_} = 1
+      for grep { /\w{$min_length,}/ }
+      map { substr($_, 0, 1, ''); $_ }
+      map { $_->variables }
+      @{ $document->find('PPI::Statement::Variable') || [] };
+    $result->{$_} = 1
+      for grep { /\w{$min_length,}/ }
+      map { $_->name } @{ $document->find('PPI::Statement::Sub') || [] };
 }
 
-
 sub report {
-    my $self = shift;
+    my $self   = shift;
     my @result = sort $self->result_keys;
     wantarray ? @result : \@result;
 }
@@ -71,40 +58,35 @@ sub report_to_file {
     close $fh or die "can't close $fh: $!\n";
 }
 
-
 sub parse {
-    my $self = shift;
+    my $self    = shift;
     my $verbose = $self->verbose;
-    find(sub {
-        return unless -f && /\.pm$/;
+    find(
+        sub {
+            return unless -f && /\.pm$/;
 
-        # We can see a file more than once if we have nested paths in @INC, so
-        # check
-
-        our %seen;
-        return if $seen{$File::Find::name}++;
-
-        warn "processing $File::Find::name\n" if $verbose;
-        $self->gather($_);
-    }, $self->dirs);
-
-    $self; # for chaining
+          # We can see a file more than once if we have nested paths in @INC, so
+          # check
+            our %seen;
+            return if $seen{$File::Find::name}++;
+            warn "processing $File::Find::name\n" if $verbose;
+            $self->gather($_);
+        },
+        $self->dirs
+    );
+    $self;    # for chaining
 }
-
-
 1;
-
-
 __END__
 
-
-
 =head1 NAME
 
-Vim::Complete - Generate autocompletion information for vim
+Vim::Complete - Generate auto completion information for vim
 
 =head1 SYNOPSIS
 
+    my (@dirs, $verbose, $min_length);
+    my $filename = '...';
     Vim::Complete->new(
         dirs       => \@dirs,
         verbose    => $verbose,
@@ -113,7 +95,7 @@ Vim::Complete - Generate autocompletion information for vim
 
 =head1 DESCRIPTION
 
-Vim has a good autocompletion mechanism. In insert mode, you can type
+Vim has a good auto completion mechanism. In insert mode, you can type
 Control-n to complete on the current string; you can cycle through the
 possible completions by repeatedly typing Control-n. See C<:help complete> in
 vim for more information.
@@ -147,14 +129,14 @@ command-line frontend to Vim::Complete.
 You can tell Vim::Complete to only use identifiers that are of a certain
 minimum length. An identifier that is only one character long (such as C<$x>)
 doesn't need to be completed. If you would include two-character identifiers,
-you might throw off the autocompletion by having to cycle through too many
+you might throw off the auto completion by having to cycle through too many
 identifiers. So the default minimum length is 3.
 
 =head1 METHODS
 
 =over 4
 
-=item new
+=item C<new>
 
     my $obj = Vim::Complete->new;
     my $obj = Vim::Complete->new(%args);
@@ -165,43 +147,43 @@ component is initialized by calling the method of the same name with the given
 value. If called with a single hash reference, it is dereferenced and its
 key/value pairs are set as described before.
 
-=item clear_dirs
+=item C<clear_dirs>
 
     $obj->clear_dirs;
 
 Deletes all elements from the array.
 
-=item clear_min_length
+=item C<clear_min_length>
 
     $obj->clear_min_length;
 
 Clears the value.
 
-=item clear_result
+=item C<clear_result>
 
     $obj->clear_result;
 
 Deletes all keys and values from the hash.
 
-=item clear_verbose
+=item C<clear_verbose>
 
     $obj->clear_verbose;
 
 Clears the boolean value by setting it to 0.
 
-=item count_dirs
+=item C<count_dirs>
 
     my $count = $obj->count_dirs;
 
 Returns the number of elements in the array.
 
-=item delete_result
+=item C<delete_result>
 
     $obj->delete_result(@keys);
 
 Takes a list of keys and deletes those keys from the hash.
 
-=item dirs
+=item C<dirs>
 
     my @values    = $obj->dirs;
     my $array_ref = $obj->dirs;
@@ -213,19 +195,19 @@ array in list context, or a reference to the array in scalar context. If
 called with arguments, it expands array references found therein and sets the
 values.
 
-=item dirs_clear
+=item C<dirs_clear>
 
     $obj->dirs_clear;
 
 Deletes all elements from the array.
 
-=item dirs_count
+=item C<dirs_count>
 
     my $count = $obj->dirs_count;
 
 Returns the number of elements in the array.
 
-=item dirs_index
+=item C<dirs_index>
 
     my $element   = $obj->dirs_index(3);
     my @elements  = $obj->dirs_index(@indices);
@@ -236,19 +218,19 @@ If only one index is given, the corresponding array element is returned. If
 several indices are given, the result is returned as an array in list context
 or as an array reference in scalar context.
 
-=item dirs_pop
+=item C<dirs_pop>
 
     my $value = $obj->dirs_pop;
 
 Pops the last element off the array, returning it.
 
-=item dirs_push
+=item C<dirs_push>
 
     $obj->dirs_push(@values);
 
 Pushes elements onto the end of the array.
 
-=item dirs_set
+=item C<dirs_set>
 
     $obj->dirs_set(1 => $x, 5 => $y);
 
@@ -256,13 +238,13 @@ Takes a list of index/value pairs and for each pair it sets the array element
 at the indicated index to the indicated value. Returns the number of elements
 that have been set.
 
-=item dirs_shift
+=item C<dirs_shift>
 
     my $value = $obj->dirs_shift;
 
 Shifts the first element off the array, returning it.
 
-=item dirs_splice
+=item C<dirs_splice>
 
     $obj->dirs_splice(2, 1, $x, $y);
     $obj->dirs_splice(-1);
@@ -282,20 +264,20 @@ offset and the length are omitted, removes everything. If the offset is past
 the end of the array, it issues a warning, and splices at the end of the
 array.
 
-=item dirs_unshift
+=item C<dirs_unshift>
 
     $obj->dirs_unshift(@values);
 
 Unshifts elements onto the beginning of the array.
 
-=item exists_result
+=item C<exists_result>
 
     if ($obj->exists_result($key)) { ... }
 
 Takes a key and returns a true value if the key exists in the hash, and a
 false value otherwise.
 
-=item index_dirs
+=item C<index_dirs>
 
     my $element   = $obj->index_dirs(3);
     my @elements  = $obj->index_dirs(@indices);
@@ -306,13 +288,13 @@ If only one index is given, the corresponding array element is returned. If
 several indices are given, the result is returned as an array in list context
 or as an array reference in scalar context.
 
-=item keys_result
+=item C<keys_result>
 
     my @keys = $obj->keys_result;
 
 Returns a list of all hash keys in no particular order.
 
-=item min_length
+=item C<min_length>
 
     my $value = $obj->min_length;
     $obj->min_length($value);
@@ -320,25 +302,25 @@ Returns a list of all hash keys in no particular order.
 A basic getter/setter method. If called without an argument, it returns the
 value. If called with a single argument, it sets the value.
 
-=item min_length_clear
+=item C<min_length_clear>
 
     $obj->min_length_clear;
 
 Clears the value.
 
-=item pop_dirs
+=item C<pop_dirs>
 
     my $value = $obj->pop_dirs;
 
 Pops the last element off the array, returning it.
 
-=item push_dirs
+=item C<push_dirs>
 
     $obj->push_dirs(@values);
 
 Pushes elements onto the end of the array.
 
-=item result
+=item C<result>
 
     my %hash     = $obj->result;
     my $hash_ref = $obj->result;
@@ -363,38 +345,38 @@ If called with exactly one hash reference, it updates the hash with the given
 key/value pairs, then returns the hash in list context, or a reference to the
 hash in scalar context.
 
-=item result_clear
+=item C<result_clear>
 
     $obj->result_clear;
 
 Deletes all keys and values from the hash.
 
-=item result_delete
+=item C<result_delete>
 
     $obj->result_delete(@keys);
 
 Takes a list of keys and deletes those keys from the hash.
 
-=item result_exists
+=item C<result_exists>
 
     if ($obj->result_exists($key)) { ... }
 
 Takes a key and returns a true value if the key exists in the hash, and a
 false value otherwise.
 
-=item result_keys
+=item C<result_keys>
 
     my @keys = $obj->result_keys;
 
 Returns a list of all hash keys in no particular order.
 
-=item result_values
+=item C<result_values>
 
     my @values = $obj->result_values;
 
 Returns a list of all hash values in no particular order.
 
-=item set_dirs
+=item C<set_dirs>
 
     $obj->set_dirs(1 => $x, 5 => $y);
 
@@ -402,19 +384,19 @@ Takes a list of index/value pairs and for each pair it sets the array element
 at the indicated index to the indicated value. Returns the number of elements
 that have been set.
 
-=item set_verbose
+=item C<set_verbose>
 
     $obj->set_verbose;
 
 Sets the boolean value to 1.
 
-=item shift_dirs
+=item C<shift_dirs>
 
     my $value = $obj->shift_dirs;
 
 Shifts the first element off the array, returning it.
 
-=item splice_dirs
+=item C<splice_dirs>
 
     $obj->splice_dirs(2, 1, $x, $y);
     $obj->splice_dirs(-1);
@@ -434,19 +416,19 @@ offset and the length are omitted, removes everything. If the offset is past
 the end of the array, it issues a warning, and splices at the end of the
 array.
 
-=item unshift_dirs
+=item C<unshift_dirs>
 
     $obj->unshift_dirs(@values);
 
 Unshifts elements onto the beginning of the array.
 
-=item values_result
+=item C<values_result>
 
     my @values = $obj->values_result;
 
 Returns a list of all hash values in no particular order.
 
-=item verbose
+=item C<verbose>
 
     $obj->verbose($value);
     my $value = $obj->verbose;
@@ -455,19 +437,19 @@ If called without an argument, returns the boolean value (0 or 1). If called
 with an argument, it normalizes it to the boolean value. That is, the values
 0, undef and the empty string become 0; everything else becomes 1.
 
-=item verbose_clear
+=item C<verbose_clear>
 
     $obj->verbose_clear;
 
 Clears the boolean value by setting it to 0.
 
-=item verbose_set
+=item C<verbose_set>
 
     $obj->verbose_set;
 
 Sets the boolean value to 1.
 
-=item parse
+=item C<parse>
 
 Assumes that C<dir()>, and optionally C<verbose()> and C<min_length()>, have
 been set and starts to look in the directories for files ending in C<.pm>. For
@@ -476,17 +458,17 @@ each file it gathers information using C<gather()>.
 Returns the Vim::Complete object so method calls can be chained as seen in the
 L</SYNOPSIS>.
 
-=item report
+=item C<report>
 
 Takes all the gathered findings and returns the list of identifiers. Returns
 an array in list context, or a reference to the array in scalar context.
 
-=item report_to_file
+=item C<report_to_file>
 
 Takes as argument a filename. Writes the report generated by C<report()> to
 the file.
 
-=item gather
+=item C<gather>
 
 Takes a filename of a module, parses the source code and makes a note of the
 package names, subroutine names and variable names it sees.
@@ -536,7 +518,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Vim-Complete/>.
 
 =head1 AUTHORS
 
@@ -544,11 +526,9 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by the authors.
+Copyright 2007-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
 =cut
-
